Distributed training on MNIST dataset
==========================================

.. include:: ../../../tutorials/distributed-ml/torch-tutorial-1-mnist/README.md
   :parser: myst_parser.sphinx_
   :start-line: 2

train.py
++++++++

.. literalinclude:: ../../../tutorials/distributed-ml/torch-tutorial-1-mnist/train.py
   :language: python

config.yaml
+++++++++++

.. literalinclude:: ../../../tutorials/distributed-ml/torch-tutorial-1-mnist/config.yaml
   :language: yaml


slurm.sh
++++++++

.. literalinclude:: ../../../tutorials/distributed-ml/torch-tutorial-1-mnist/slurm.sh
   :language: bash


runall.sh
+++++++++

.. literalinclude:: ../../../tutorials/distributed-ml/torch-tutorial-1-mnist/runall.sh
   :language: bash
